# Generated by Django 2.1.4 on 2019-04-18 07:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_references', '0002_reference_bibjson'),
    ]

    operations = [
        migrations.AddField(
            model_name='reference',
            name='sort_order',
            field=models.IntegerField(blank=True, editable=False, null=True),
        ),
    ]
